@@ -1,12 +1,18 @@
 "grasp.export" <-
 function (var = gr.predmat) 
 {
-    cat("*****************************************************", "\n")
-    cat("**********        R-GRASP EXPORT           **********", "\n")
-    cat("********** Exporting results in txt format **********", "\n")
-    cat("**********      GRASP by A. Lehmann        **********", "\n")
-    cat("**********    Ported to R by F. Fivaz      **********", "\n")
-    cat("*****************************************************", "\n")
+    cat("*****************************************************", 
+        "\n")
+    cat("**********        R-GRASP EXPORT           **********", 
+        "\n")
+    cat("********** Exporting results in txt format **********", 
+        "\n")
+    cat("**********      GRASP by A. Lehmann        **********", 
+        "\n")
+    cat("**********    Ported to R by F. Fivaz      **********", 
+        "\n")
+    cat("*****************************************************", 
+        "\n")
     cat("\n")
     cat(date(), "\n")
     cat("\n")
@@ -15,7 +21,7 @@ function (var = gr.predmat)
     cat("Response name:", Yname, "\n")
     cat("\n")
     file <- paste("pred_", Yname, ".txt", sep = "")
-    gr.export <- var[,gr.Yi]
+    gr.export <- var[, gr.Yi]
     glmax <- max(var)
     glength <- length(var)
     cat("Converting to percents (and integer)...", "\n")
@@ -25,6 +31,7 @@ function (var = gr.predmat)
     cat("Writing file", file, "to disk...", "\n")
     write.table(to.export, file = file, sep = ",", row.names = F)
     cat("\n")
-    cat("**********      R-GRASP EXPORT END         **********", "\n")
+    cat("**********      R-GRASP EXPORT END         **********", 
+        "\n")
     cat("\n")
 }
